# Changelog

## [0.12.0](https://github.com/SoferAi/soferai-py/compare/v0.11.0...v0.12.0) (2025-10-05)


### Features

* **fern:** regeneration october 5, 2025 ([#267](https://github.com/SoferAi/soferai-py/issues/267)) ([0d870be](https://github.com/SoferAi/soferai-py/commit/0d870be40248a7cc5768952f9dc4cf0cccc82d36))
* **fern:** regeneration september 26, 2025 ([#258](https://github.com/SoferAi/soferai-py/issues/258)) ([87d1393](https://github.com/SoferAi/soferai-py/commit/87d13936c0b246bc600d4e9dda63b44e4e0f26d4))

## [0.11.0](https://github.com/SoferAi/soferai-py/compare/v0.10.1...v0.11.0) (2025-08-15)


### Features

* **fern:** regeneration august 13, 2025 ([#234](https://github.com/SoferAi/soferai-py/issues/234)) ([80e3b31](https://github.com/SoferAi/soferai-py/commit/80e3b3182947ccbba0bcf4a2122e6957c539b60f))
* **fern:** regeneration august 15, 2025 ([#238](https://github.com/SoferAi/soferai-py/issues/238)) ([396b88f](https://github.com/SoferAi/soferai-py/commit/396b88f8972558830c563aa1abe051620f94469e))
* **fern:** regeneration july 2, 2025 ([#206](https://github.com/SoferAi/soferai-py/issues/206)) ([4637c16](https://github.com/SoferAi/soferai-py/commit/4637c167067981497c7d72f2f8cda37d0e8181ca))
* **fern:** regeneration july 29, 2025 ([#214](https://github.com/SoferAi/soferai-py/issues/214)) ([7cc16cb](https://github.com/SoferAi/soferai-py/commit/7cc16cb95a3ef2b274b1978dd5bf93b2ecd3876c))
* **fern:** regeneration july 29, 2025 ([#220](https://github.com/SoferAi/soferai-py/issues/220)) ([2c85360](https://github.com/SoferAi/soferai-py/commit/2c85360ebb1fa4332683a2e5f2d51e3b9f022685))
* **fern:** regeneration july 29, 2025 ([#221](https://github.com/SoferAi/soferai-py/issues/221)) ([8dd2c80](https://github.com/SoferAi/soferai-py/commit/8dd2c8053a3ee97d940339b01a783f71caef1b85))
* **fern:** regeneration july 29, 2025 ([#222](https://github.com/SoferAi/soferai-py/issues/222)) ([9e29d1b](https://github.com/SoferAi/soferai-py/commit/9e29d1bdbba2ef55199904c779e66c9fecbcc718))
* **fern:** regeneration june 15, 2025 ([#183](https://github.com/SoferAi/soferai-py/issues/183)) ([e64eb56](https://github.com/SoferAi/soferai-py/commit/e64eb569f57092e49e5ec0b7e016d38236268b72))
* **fern:** regeneration may 27, 2025 ([#168](https://github.com/SoferAi/soferai-py/issues/168)) ([5abd056](https://github.com/SoferAi/soferai-py/commit/5abd05646fea98545b780ce4b7e7a41c59b770fc))


### Bug Fixes

* 0.11.0 ([#239](https://github.com/SoferAi/soferai-py/issues/239)) ([61729f9](https://github.com/SoferAi/soferai-py/commit/61729f9487fb693a9e20825c4751de6e0ce6baf4))

## [0.10.1](https://github.com/SoferAi/soferai-py/compare/v0.10.0...v0.10.1) (2025-05-27)


### Bug Fixes

* fixed-test ([#165](https://github.com/SoferAi/soferai-py/issues/165)) ([6367869](https://github.com/SoferAi/soferai-py/commit/6367869054a9eeddeb8f98af849efaf9d1e8b74d))

## [0.10.0](https://github.com/SoferAi/soferai-py/compare/v0.9.0...v0.10.0) (2025-05-27)


### Features

* **fern:** regeneration may 27, 2025 ([#163](https://github.com/SoferAi/soferai-py/issues/163)) ([09eddad](https://github.com/SoferAi/soferai-py/commit/09eddadb8f180396412b978f7c297c03da2dd9c1))

## [0.9.0](https://github.com/SoferAi/soferai-py/compare/v0.8.0...v0.9.0) (2025-05-16)


### Features

* **fern:** regeneration may 16, 2025 ([#155](https://github.com/SoferAi/soferai-py/issues/155)) ([6aa4ed1](https://github.com/SoferAi/soferai-py/commit/6aa4ed120f831ee423ea54fe517ab70a024e8989))


### Bug Fixes

* updated-tests ([#157](https://github.com/SoferAi/soferai-py/issues/157)) ([2a0eb6d](https://github.com/SoferAi/soferai-py/commit/2a0eb6d367fb0dc12e8c936d3b11b2e9a72d7adb))

## [0.8.0](https://github.com/SoferAi/soferai-py/compare/v0.7.0...v0.8.0) (2025-04-25)


### Features

* **fern:** regeneration april 25, 2025 ([#140](https://github.com/SoferAi/soferai-py/issues/140)) ([309cc97](https://github.com/SoferAi/soferai-py/commit/309cc9736b1b3b460d3172198a104df8ebbc0c2e))

## [0.7.0](https://github.com/SoferAi/soferai-py/compare/v0.6.0...v0.7.0) (2025-04-25)


### Features

* **fern:** regeneration april 25, 2025 ([#137](https://github.com/SoferAi/soferai-py/issues/137)) ([2c6fd27](https://github.com/SoferAi/soferai-py/commit/2c6fd27ff4db51cd48758b32537c499103a142ba))

## [0.6.0](https://github.com/SoferAi/soferai-py/compare/v0.5.0...v0.6.0) (2025-03-13)


### Features

* **fern:** regeneration march 12, 2025 ([#113](https://github.com/SoferAi/soferai-py/issues/113)) ([fae6c38](https://github.com/SoferAi/soferai-py/commit/fae6c38047a08a485b6e27a0b24b44dac9abc0d2))
* **fern:** regeneration march 3, 2025 ([#104](https://github.com/SoferAi/soferai-py/issues/104)) ([017061f](https://github.com/SoferAi/soferai-py/commit/017061fcd4c1b3484879f87482928c2daabd07f1))

## [0.5.0](https://github.com/SoferAi/soferai-py/compare/v0.4.0...v0.5.0) (2025-02-13)


### Features

* basic tests ([#78](https://github.com/SoferAi/soferai-py/issues/78)) ([e9d044e](https://github.com/SoferAi/soferai-py/commit/e9d044ee45a1697dbd29133a635fbe128b832cdc))
* **fern:** regeneration february 9, 2025 ([#66](https://github.com/SoferAi/soferai-py/issues/66)) ([a3e6852](https://github.com/SoferAi/soferai-py/commit/a3e6852ecd8ed72c80bf4477a30f274ed3708a0a))
* **fern:** regeneration january 27, 2025 ([#50](https://github.com/SoferAi/soferai-py/issues/50)) ([ebcad2f](https://github.com/SoferAi/soferai-py/commit/ebcad2f72fd38673f2e7bbb0188305d7ee450648))

## [0.4.0](https://github.com/SoferAi/soferai-py/compare/v0.3.0...v0.4.0) (2025-01-27)


### Features

* **fern:** regeneration december 31, 2024 ([#26](https://github.com/SoferAi/soferai-py/issues/26)) ([9d1d490](https://github.com/SoferAi/soferai-py/commit/9d1d4903ade5955ee6bbc0a54a194abc665504ce))
* **fern:** regeneration january 22, 2025 ([#35](https://github.com/SoferAi/soferai-py/issues/35)) ([e511f48](https://github.com/SoferAi/soferai-py/commit/e511f48c6a28b450eb5f1fa422f6f2721a3c9686))
* **fern:** regeneration january 27, 2025 ([#48](https://github.com/SoferAi/soferai-py/issues/48)) ([042cf1a](https://github.com/SoferAi/soferai-py/commit/042cf1a48b27c603e9536bbdee2d3c4773b014be))


### Bug Fixes

* add renovate.json to fernignore ([#47](https://github.com/SoferAi/soferai-py/issues/47)) ([99591ed](https://github.com/SoferAi/soferai-py/commit/99591ed53c21349b0ab9c0b7b77b527b72b253a7))

## [0.3.0](https://github.com/SoferAi/soferai-py/compare/v0.2.0...v0.3.0) (2024-12-24)


### Features

* **fern:** regeneration december 24, 2024 ([#20](https://github.com/SoferAi/soferai-py/issues/20)) ([e579042](https://github.com/SoferAi/soferai-py/commit/e579042f7c91c14cd9fa5f41eaf5363d8e1f1b8f))


### Bug Fixes

* set httpx dependency to something supabase can handle ([#22](https://github.com/SoferAi/soferai-py/issues/22)) ([c626286](https://github.com/SoferAi/soferai-py/commit/c626286dc098f44c6af6c354efe876180c726b8b))
* update ci and fernignore ([#18](https://github.com/SoferAi/soferai-py/issues/18)) ([53b5a55](https://github.com/SoferAi/soferai-py/commit/53b5a55ff5fe3395d8041fb604f1f35459ea3993))

## [0.2.0](https://github.com/SoferAi/soferai-py/compare/v0.1.0...v0.2.0) (2024-12-23)


### Features

* **🌿:** regenerate ([#14](https://github.com/SoferAi/soferai-py/issues/14)) ([82a04fb](https://github.com/SoferAi/soferai-py/commit/82a04fb7c6bdbdb9769981fb75be7a05b525fc7f))


### Bug Fixes

* add stuff to fernignore ([#12](https://github.com/SoferAi/soferai-py/issues/12)) ([52aa5a9](https://github.com/SoferAi/soferai-py/commit/52aa5a91c3e89cd1e0c8d42b536b90ac45653fac))

## 0.1.0 (2024-12-23)


### Features

* **🌿:** fern regeneration 12-23-2024 ([#6](https://github.com/SoferAi/soferai-py/issues/6)) ([931cb07](https://github.com/SoferAi/soferai-py/commit/931cb074f5a606ee081ab7c1ec43194c889af82c))
* basic example ([686b65b](https://github.com/SoferAi/soferai-py/commit/686b65bfe40365c30200f3d9b8f716b5bfdd91cc))
* **ci:** add release please and fernignore ([#3](https://github.com/SoferAi/soferai-py/issues/3)) ([b2a5aae](https://github.com/SoferAi/soferai-py/commit/b2a5aae3a2c41d74dee66687252cb5c9e62bd25c))
